@@ -67,6 +67,8 @@ class CProblem extends CApiService {
 			'eventid_till'				=> null,
 			'acknowledged'				=> null,
 			'suppressed'				=> null,
+			'recent'					=> null,
+			'any'						=> null,	// (internal) true if need not filtred by r_eventid
 			'evaltype'					=> TAG_EVAL_TYPE_AND_OR,
 			'tags'						=> null,
 			'recent'					=> null,
@@ -279,8 +281,8 @@ class CProblem extends CApiService {
 
 		// tags
 		if ($options['tags'] !== null && $options['tags']) {
-			$sqlParts['where'][] = CEvent::getTagsWhereCondition($options['tags'], $options['evaltype'], 'problem_tag',
-				'pt', 'p', 'eventid'
+			$sqlParts['where'][] = CApiTagHelper::addWhereCondition($options['tags'], $options['evaltype'], 'p',
+				'problem_tag', 'eventid'
 			);
 		}
 
@@ -425,12 +427,11 @@ class CProblem extends CApiService {
 						' GROUP BY a.eventid'
 				), 'eventid');
 
-				foreach ($result as &$event) {
-					$event['acknowledges'] = array_key_exists($event['eventid'], $acknowledges)
-						? $acknowledges[$event['eventid']]['rowscount']
-						: 0;
+				foreach ($result as $eventid => $event) {
+					$result[$eventid]['acknowledges'] = array_key_exists($eventid, $acknowledges)
+						? $acknowledges[$eventid]['rowscount']
+						: '0';
 				}
-				unset($event);
 			}
 		}
 
@@ -452,8 +453,8 @@ class CProblem extends CApiService {
 			foreach ($result as &$problem) {
 				if (array_key_exists('suppression_data', $problem)) {
 					$problem['suppressed'] = $problem['suppression_data']
-						? ZBX_PROBLEM_SUPPRESSED_TRUE
-						: ZBX_PROBLEM_SUPPRESSED_FALSE;
+						? (string) ZBX_PROBLEM_SUPPRESSED_TRUE
+						: (string) ZBX_PROBLEM_SUPPRESSED_FALSE;
 				}
 				else {
 					$suppressed_eventids[] = $problem['eventid'];
@@ -469,8 +470,8 @@ class CProblem extends CApiService {
 				$suppressed_eventids = array_flip(zbx_objectValues($suppressed_events, 'eventid'));
 				foreach ($result as &$problem) {
 					$problem['suppressed'] = array_key_exists($problem['eventid'], $suppressed_eventids)
-						? ZBX_PROBLEM_SUPPRESSED_TRUE
-						: ZBX_PROBLEM_SUPPRESSED_FALSE;
+						? (string) ZBX_PROBLEM_SUPPRESSED_TRUE
+						: (string) ZBX_PROBLEM_SUPPRESSED_FALSE;
 				}
 				unset($problem);
 			}
@@ -520,7 +521,7 @@ class CProblem extends CApiService {
 	 * @param array $usrgrpids
 	 * @param array $sqlParts
 	 *
-	 * @return string
+	 * @return array
 	 */
 	protected static function addTagFilterSqlParts(array $usrgrpids, array $sqlParts) {
 		$tag_filters = CEvent::getTagFilters($usrgrpids);
